@@ -1013,3 +1013,70 @@ dat.expand.fct		<- function(
 
 
 
+
+
+
+
+
+
+
+###
+### Helper function to check sparse matrix for collinearities
+###
+
+
+#' @keywords internal
+#'
+#' @importFrom methods as
+corSparse <- function(X, Y = NULL, cov = FALSE) {
+
+  X <- methods::as(X,"dgCMatrix")
+  n <- nrow(X)
+  muX <- colMeans(X)
+
+  if (!is.null(Y)) {
+    stopifnot( nrow(X) == nrow(Y) )
+    Y <- methods::as(Y,"dgCMatrix")
+    muY <- colMeans(Y)
+    covmat <- ( as.matrix(crossprod(X,Y)) - n*tcrossprod(muX,muY) ) / (n-1)
+    sdvecX <- sqrt( (colSums(X^2) - n*muX^2) / (n-1) )
+    sdvecY <- sqrt( (colSums(Y^2) - n*muY^2) / (n-1) )
+    cormat <- covmat/tcrossprod(sdvecX,sdvecY)
+  } else {
+    covmat <- ( as.matrix(crossprod(X)) - n*tcrossprod(muX) ) / (n-1)
+    sdvec <- sqrt(diag(covmat))
+    cormat <- covmat/tcrossprod(sdvec)
+  }
+
+  if (cov) {
+    dimnames(covmat) <- NULL
+    return(covmat)
+  } else {
+    dimnames(cormat) <- NULL
+    return(cormat)
+  }
+}
+
+# function 'corSparse' copied from R package 'qlcMatrix', which was scheduled to be archived 2023-11-29
+#
+# Pearson correlation matrix between columns of X, Y
+# http://stackoverflow.com/questions/5888287/running-cor-or-any-variant-over-a-sparse-matrix-in-r
+#
+# covmat uses E[(X-muX)'(Y-muY)] = E[X'Y] - muX'muY
+# with sample correction n/(n-1) this leads to cov = ( X'Y - n*muX'muY ) / (n-1)
+#
+# the sd in the case Y!=NULL uses E[X-mu]^2 = E[X^2]-mu^2
+# with sample correction n/(n-1) this leads to sd^2 = ( X^2 - n*mu^2 ) / (n-1)
+#
+# Note that results larger than 1e4 x 1e4 will become very slow, because the resulting matrix is not sparse anymore.
+#
+#Further alternative:
+#replace function 'corSparse()' from 'qlcMatrix'-package based on the following post (according to
+#function documentation, the implementation is a slightly modified version of the post):
+#https://stackoverflow.com/questions/5888287/running-cor-or-any-variant-over-a-sparse-matrix-in-r
+
+
+
+
+
+
